//----------------------------------------------------------------------------
//
//************************************************************************
// * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
// *                                                                     *
// * This sample program is owned by International Business Machines     *
// * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
// * and licensed, not sold.                                             *
// *                                                                     *
// * You may copy, modify, and distribute this sample program in any     *
// * form without payment to IBM,  for any purpose including developing, *
// * using, marketing or distributing programs that include or are       *
// * derivative works of the sample program.                             *
// *                                                                     *
// * The sample program is provided to you on an "AS IS" basis, without  *
// * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
// * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
// * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
// * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
// * limitation of implied warranties, so the above limitations or       *
// * exclusions may not apply to you.  IBM shall not be liable for any   *
// * damages you suffer as a result of using, modifying or distributing  *
// * the sample program or its derivatives.                              *
// *                                                                     *
// * Each copy of any portion of this sample program or any derivative   *
// * work,  must include the above copyright notice and disclaimer of    *
// * warranty.                                                           *
// *                                                                     *
//************************************************************************
//
//***************************************************************************
//
// SOURCE FILE NAME: dbconn_ODBC_CLI.c
//
// DESCRIPTION:      How to connect to a database using ODBC/CLI
//
// COMPILATION INSTRUCTIONS:  
//    To make this program a CLI program:   bldappCLI.bat  dbconn_ODBC_CLI
//    or
//    To make this program an ODBC program: bldappODBC.bat dbconn_ODBC_CLI
//
// EXECUTION INSTRUCTIONS:
//    dbconn_ODBC_CLI <database name> <userid> <password>
//
//***************************************************************************

/* Standard C/C++ Headers */ 
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* DB2 ODBC Header */
#include <sqlcli1.h>

/* Local Function Prototypes */
int ErrorHandler(SQLRETURN rc,
                 char*     errorString,
                 SQLHENV   henv,
                 SQLHDBC   hdbc,
                 SQLHSTMT  hstmt);

/* Main Program */
int main(int argc, char** argv)
{
   /* Handles */
   SQLHENV  henv = SQL_NULL_HENV;
   SQLHDBC  hdbc = SQL_NULL_HDBC;
   SQLHSTMT hstmt= SQL_NULL_HSTMT;

   /* Local variables */
   SQLRETURN     rc;
   SQLCHAR       statement[32761];
   SQLCHAR       mycolout[2];
   SQLINTEGER    mycoloutlen = 0;
   char*         errorString;
   char          dbname[8 + 1];
   char          user[18 + 1];
   char          pswd[30 + 1];

   if (argc < 4) {
       printf ("Usage: dbconn_ODBC_CLI <database name> <userid> <password>\n");
       exit (0);
   }
   strcpy (dbname, argv[1]);
   strcpy (user,   argv[2]);
   strcpy (pswd,   argv[3]);

   errorString="Allocating Environment Handle";
   rc = SQLAllocHandle(SQL_HANDLE_ENV,
                       SQL_NULL_HANDLE,
                       &henv);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Setting Environment Attributes";
   rc = SQLSetEnvAttr(henv, SQL_ATTR_ODBC_VERSION,
        (SQLPOINTER)SQL_OV_ODBC3, SQL_IS_INTEGER);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);


   errorString="Allocating Connection Handle";
   rc = SQLAllocHandle(SQL_HANDLE_DBC,
                       henv,
                       &hdbc);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Getting a Connection";
   /* connect to the database */
        rc = SQLConnect(hdbc,
        (SQLCHAR *)dbname,
         SQL_NTS,
        (SQLCHAR *)user,
         SQL_NTS,
        (SQLCHAR *)pswd,
         SQL_NTS);
    if (rc != SQL_SUCCESS)
        ErrorHandler(rc, errorString, henv, hdbc, hstmt);
    else {
        printf ("\n  Successful connection to '%s' db using ODBC/CLI \n",dbname);
    }

   errorString="Allocating Statement Handle";
   rc = SQLAllocHandle(SQL_HANDLE_STMT,
                       hdbc,
                       &hstmt);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Selecting a record";
   strcpy(statement,"SELECT IBMREQD");
   strcat(statement,"  FROM SYSIBM.SYSDUMMY1;");

   rc = SQLExecDirect(hstmt,
                      statement,
                      SQL_NTS);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Binding output column";
   rc = SQLBindCol(hstmt, 1,
                   SQL_C_CHAR,
                   mycolout,
                   sizeof(mycolout),
                   &mycoloutlen);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);


   errorString="Fetching Results";
   while((rc = SQLFetch(hstmt)) == SQL_SUCCESS
         || rc == SQL_SUCCESS_WITH_INFO)
   {
     /* Print data */
     printf("  Successful retrieval of record.  Column 'IBMREQD' has a value of '%s'\n",mycolout);
   }

   if(rc != SQL_NO_DATA_FOUND)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Closing Cursor";
   rc = SQLCloseCursor(hstmt);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Freeing Statement Resources";
   rc = SQLFreeStmt(hstmt, SQL_RESET_PARAMS);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Freeing Statement Handle";
   rc = SQLFreeHandle(SQL_HANDLE_STMT, hstmt);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Disconnecting";
   rc = SQLDisconnect(hdbc);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);
   else {
      printf ("  Successful Disconnection from database '%s'\n",dbname);
   }

   errorString="Freeing Connection Handle";
   rc = SQLFreeHandle(SQL_HANDLE_DBC, hdbc);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   errorString="Freeing Environment Handle";
   rc = SQLFreeHandle(SQL_HANDLE_ENV, henv);
   if(rc != SQL_SUCCESS)
      ErrorHandler(rc, errorString, henv, hdbc, hstmt);

   printf ("  End of Program\n");
   return 0;
}

/* ErrorHandler()      */
/* - Print Diagnostics */
int ErrorHandler(SQLRETURN rc,
                 char*     errorString,
                 SQLHENV   henv,
                 SQLHDBC   hdbc,
                 SQLHSTMT  hstmt)
{
   SQLCHAR     msgtext[SQL_MAX_MESSAGE_LENGTH + 1];
   SQLCHAR     msqlstate[SQL_SQLSTATE_SIZE + 1];
   SQLINTEGER  msqlcode;
   SQLSMALLINT length, i;
   SQLRETURN   prc;
   struct sqlca sqlca;
   memset(&sqlca, '\0', sizeof(sqlca));

   printf("\n*** Error %s ***\n\n", errorString);
  /* Environment Messages */
  if(henv != SQL_NULL_HENV)
  {
     i = 1;
     while(SQLGetDiagRec(SQL_HANDLE_ENV,

                           henv,
                           i,
                           msqlstate,
                           &msqlcode,
                           msgtext,
                           SQL_MAX_MESSAGE_LENGTH + 1,
                           &length ) == SQL_SUCCESS)
       {
          printf( "%s \n", msgtext ) ;
          i++ ;
       }
    }

/* Connection Messages */
if(hdbc != SQL_NULL_HDBC)
{
   i = 1;
      while(SQLGetDiagRec(SQL_HANDLE_DBC,
                           hdbc,
                           i,
                           msqlstate,
                           &msqlcode,
                           msgtext,
                           SQL_MAX_MESSAGE_LENGTH + 1,
                           &length ) == SQL_SUCCESS)
       {
          printf( "%s \n", msgtext ) ;
          i++ ;
       }
    }

/* Statement Messages */
if(hstmt != SQL_NULL_HSTMT)
{
   i = 1;
      while(SQLGetDiagRec(SQL_HANDLE_STMT,
                           hstmt,
                           i,
                           msqlstate,
                           &msqlcode,
                           msgtext,
                           SQL_MAX_MESSAGE_LENGTH + 1,
                           &length ) == SQL_SUCCESS)
       {
          printf( "%s \n", msgtext ) ;
          i++ ;
       }
    }


   if(rc != SQL_SUCCESS_WITH_INFO)
   {
     exit(-1); 
   }

   return 0;
}  // dbconn_ODBC_CLI