//----------------------------------------------------------------------------
//
//************************************************************************
// * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
// *                                                                     *
// * This sample program is owned by International Business Machines     *
// * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
// * and licensed, not sold.                                             *
// *                                                                     *
// * You may copy, modify, and distribute this sample program in any     *
// * form without payment to IBM,  for any purpose including developing, *
// * using, marketing or distributing programs that include or are       *
// * derivative works of the sample program.                             *
// *                                                                     *
// * The sample program is provided to you on an "AS IS" basis, without  *
// * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
// * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
// * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
// * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
// * limitation of implied warranties, so the above limitations or       *
// * exclusions may not apply to you.  IBM shall not be liable for any   *
// * damages you suffer as a result of using, modifying or distributing  *
// * the sample program or its derivatives.                              *
// *                                                                     *
// * Each copy of any portion of this sample program or any derivative   *
// * work,  must include the above copyright notice and disclaimer of    *
// * warranty.                                                           *
// *                                                                     *
//************************************************************************
//
//***************************************************************************
//
// SOURCE FILE NAME: DBConn_Type3.java
//
// DESCRIPTION:      How to connect to a database using DB2 JDBC Type 3 Driver
//
// COMPILATION INSTRUCTIONS:  
//    javac DBConn_Type3.java
//
// EXECUTION INSTRUCTIONS:
//    java DBConn_Type3 <database name> <userid> <password>
//         <server hostname> <DB2's Java Applet Server Port>
//
//***************************************************************************

import java.sql.*;

class DBConn_Type3
{

  public static void main(String argv[])
  {

   // Check arguments

   if (argv.length < 5) {
       System.out.println("Usage: java DBConn_Type3 <database name> <userid> <password>");       
       System.out.println("           <server hostname> <DB2's Java Applet Server port>");       
       return;
    }

    try
    {
     String dbname      = argv[0];
     String userId      = argv[1];
     String password    = argv[2];
     String server      = argv[3];
     String portNumber  = argv[4]; 
     String url         = "jdbc:db2://" + server + ":" + portNumber + "/" + dbname;
     String v_IBMREQD   = null;

     // Registering driver and connecting

     Class.forName("COM.ibm.db2.jdbc.net.DB2Driver").newInstance();
     Connection con = DriverManager.getConnection( url, userId, password );

     System.out.println(
      "  Successful connection to '" + dbname + "' db using JDBC type 3 driver" );

     // Retrieving a record from a table
     Statement stmt = con.createStatement();
     ResultSet rs   = stmt.executeQuery("SELECT IBMREQD FROM SYSIBM.SYSDUMMY1");

     // There is only one record in SYSIBM.SYSDUMMY1.  Note that if you are not
     // a DB2 instance owner, you may have to issue this command before running this program: 
     // db2 GRANT select on sysibm.sysdummy1 to public
     while ( rs.next() )
        {
          v_IBMREQD = rs.getString(1);
        }
     System.out.println(
     "  Successful retrieval of record.  Column 'IBMREQD' has a value of '" + v_IBMREQD + "'");

     // Closing statement 
        stmt.close();

     // Disconnecting
        con.close();        

     System.out.println(
      "  Successful Disconnection from database '" + dbname + "'" );
 
     System.out.println("  End of Program");

    } catch (Exception e) 
       {
        System.out.println("*** Error ***");
        System.out.println( e.toString() );
    }

  } // main
} // DBConn_Type3

