/*@lineinfo:filename=DBConn_Type1j*//*@lineinfo:user-code*//*@lineinfo:1^1*///----------------------------------------------------------------------------
//
//************************************************************************
// * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
// *                                                                     *
// * This sample program is owned by International Business Machines     *
// * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
// * and licensed, not sold.                                             *
// *                                                                     *
// * You may copy, modify, and distribute this sample program in any     *
// * form without payment to IBM,  for any purpose including developing, *
// * using, marketing or distributing programs that include or are       *
// * derivative works of the sample program.                             *
// *                                                                     *
// * The sample program is provided to you on an "AS IS" basis, without  *
// * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
// * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
// * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
// * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
// * limitation of implied warranties, so the above limitations or       *
// * exclusions may not apply to you.  IBM shall not be liable for any   *
// * damages you suffer as a result of using, modifying or distributing  *
// * the sample program or its derivatives.                              *
// *                                                                     *
// * Each copy of any portion of this sample program or any derivative   *
// * work,  must include the above copyright notice and disclaimer of    *
// * warranty.                                                           *
// *                                                                     *
//************************************************************************
//
//*************************************************************************************************
//
// SOURCE FILE NAME: DbConn_Type1j.sqlj
//
// DESCRIPTION:      How to connect to a database using DB2 UDB JDBC Type 1 Driver 
//                   (JDBC-ODBC Driver) using SQLJ
//
// COMPILATION INSTRUCTIONS:  
//    bldsqljType2U.bat DBConn_Type1j <dbname> <userid> <password> 
//    or
//    bldsqljType4.bat  DBConn_Type1j <dbname> <userid> <password> <server_hostname> <port number> 
//
// EXECUTION INSTRUCTIONS:
//    java DBConn_Type1j <database name> <userid> <password>
//
//*************************************************************************************************

import java.sql.*;
import sqlj.runtime.*;
import sqlj.runtime.ref.*;

class DBConn_Type1j
{
  public static void main(String argv[])
  {
   // Check arguments

   if (argv.length < 3) {
       System.out.println("Usage: java DBConn_Type1j <database name> <userid> <password>");       
       return;
    }

    try
    {
     String dbname    = argv[0];
     String userId    = argv[1];
     String password  = argv[2];
     String url       = "jdbc:odbc:" + dbname;
     String h_ibmreqd = null;

     // Registering the Type 1 driver and connecting
     Class.forName("sun.jdbc.odbc.JdbcOdbcDriver").newInstance();
     DriverManager.getConnection( url, userId, password );
     DefaultContext ctx = new DefaultContext(DriverManager.getConnection(url, userId,
                                             password) );
     DefaultContext.setDefaultContext(ctx);

     System.out.println(
     "  Successful connection to '" + dbname + "' db using SQLJ with JDBC type 1 driver" );

     // Retrieving a record from a table
     // There is only one record in SYSIBM.SYSDUMMY1.  Note that if you are not
     // a DB2 instance owner, you may have to issue this command before running this program: 
     // db2 GRANT select on sysibm.sysdummy1 to public

     /*@lineinfo:generated-code*//*@lineinfo:86^5*/

//  ************************************************************
//  #sql [ctx] { select IBMREQD  from sysibm.sysdummy1 };
//  ************************************************************

{
  sqlj.runtime.profile.RTResultSet __sJT_rtRs;
  sqlj.runtime.ConnectionContext __sJT_connCtx = ctx;
  if (__sJT_connCtx == null) sqlj.runtime.error.RuntimeRefErrors.raise_NULL_DEFAULT_CONN_CTX();
  sqlj.runtime.ExecutionContext __sJT_execCtx = __sJT_connCtx.getExecutionContext();
  if (__sJT_execCtx == null) sqlj.runtime.error.RuntimeRefErrors.raise_NULL_EXEC_CTX();
  synchronized (__sJT_execCtx) {
    sqlj.runtime.profile.RTStatement __sJT_stmt = __sJT_execCtx.registerStatement(__sJT_connCtx, DBConn_Type1j_SJProfileKeys.getKey(0), 0);
    try 
    {
      __sJT_rtRs = __sJT_execCtx.executeQuery();
    }
    finally 
    {
      __sJT_execCtx.releaseStatement();
    }
  }
  try 
  {
    sqlj.runtime.ref.ResultSetIterImpl.checkColumns(__sJT_rtRs, 1);
    if (!__sJT_rtRs.next())
    {
      sqlj.runtime.error.RuntimeRefErrors.raise_NO_ROW_SELECT_INTO();
    }
    h_ibmreqd = __sJT_rtRs.getString(1);
    if (__sJT_rtRs.next())
    {
      sqlj.runtime.error.RuntimeRefErrors.raise_MULTI_ROW_SELECT_INTO();
    }
  }
  finally 
  {
    __sJT_rtRs.close();
  }
}


//  ************************************************************

/*@lineinfo:user-code*//*@lineinfo:86^69*/
     System.out.println(
     "  Successful retrieval of record.  Column 'IBMREQD' has a value of '" + h_ibmreqd + "'");

     // Closing context, disconnecting
     if( ctx != null )
      {
        ctx.close();
      }

     System.out.println(
      "  Successful Disconnection from database '" + dbname + "'" );
 
     System.out.println("  End of Program");

    } catch (Exception e) 
       {
        System.out.println("*** Error ***");
        System.out.println( e.toString() );
       }

  } // main
}/*@lineinfo:generated-code*/class DBConn_Type1j_SJProfileKeys 
{
  private java.lang.Object[] keys;
  private final sqlj.runtime.profile.Loader loader = sqlj.runtime.RuntimeContext.getRuntime().getLoaderForClass(getClass());
  private static DBConn_Type1j_SJProfileKeys inst = null;
  public static java.lang.Object getKey(int keyNum) 
    throws java.sql.SQLException 
  {
    if (inst == null)
    {
      inst = new DBConn_Type1j_SJProfileKeys();
    }
    return inst.keys[keyNum];
  }
  private DBConn_Type1j_SJProfileKeys() 
    throws java.sql.SQLException 
  {
    keys = new java.lang.Object[1];
    keys[0] = DefaultContext.getProfileKey(loader, "DBConn_Type1j_SJProfile0");
  }
}
