//----------------------------------------------------------------------------
//
//************************************************************************
// * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
// *                                                                     *
// * This sample program is owned by International Business Machines     *
// * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
// * and licensed, not sold.                                             *
// *                                                                     *
// * You may copy, modify, and distribute this sample program in any     *
// * form without payment to IBM,  for any purpose including developing, *
// * using, marketing or distributing programs that include or are       *
// * derivative works of the sample program.                             *
// *                                                                     *
// * The sample program is provided to you on an "AS IS" basis, without  *
// * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
// * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
// * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
// * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
// * limitation of implied warranties, so the above limitations or       *
// * exclusions may not apply to you.  IBM shall not be liable for any   *
// * damages you suffer as a result of using, modifying or distributing  *
// * the sample program or its derivatives.                              *
// *                                                                     *
// * Each copy of any portion of this sample program or any derivative   *
// * work,  must include the above copyright notice and disclaimer of    *
// * warranty.                                                           *
// *                                                                     *
//************************************************************************
//
//***************************************************************************
//
// SOURCE FILE NAME: dbConn_cs_adoNET_ibmdatadb2.cs
//
// DESCRIPTION:      How to connect to a database using
//                    IBM DB2 .NET Data Provider
//
//***************************************************************************
//
//----------------------------------------------------------------------------
using IBM.Data.DB2;
using System;
using System.Data;
using System.IO;

public class ConnectDb
{
	public static void Main(String[] args)
	{
		DB2Command cmd = null;
		DB2Connection con = null;
		DB2DataReader rdr = null;
		int i;
		String connectString;
		String strMsg;
		String strSQL;
		String v_IBMREQD;
		String dbname;
		String pwd;
		String uid;

		//retrieve command-line parameters
		if (args.Length == 3)
		{
			dbname = args[0];
			uid = args[1];
			pwd = args[2];
		}
		else
		{
			//no command-line parameters specified, use default
			dbname = "SAMPLE";
			uid = "";
			pwd = "";
		}

		connectString = "Database=" + dbname + ";UID=" + uid +
			";PWD=" + pwd + ";";
		//if needed, uncomment & specify rest of connection string's
		//      keyword/value pairs
		//connectString += "Provider='IBMDADB2';";
		//connectString += "Driver={IBM DB2 ODBC DRIVER};";
		//connectString += "Server=aries.xyz.com:50000;";
		//connectString += "Connect Timeout=60;";
		//connectString += "Pooling=true;";
		//connectString += "Min Pool Size=0;";
		//connectString += "Max Pool Size=12;";
		//connectString += "Connection Reset=true;";
		//connectString += "Connection Lifetime=15;";
		try
		{
			//initialize connection object
			con = new DB2Connection(connectString);

			//define SQL query
			strSQL = "SELECT * FROM SYSIBM.SYSDUMMY1";
			
			//initialize command object
			cmd = new DB2Command();

			//set up command object properties
			cmd.Connection = con;
			cmd.CommandText = strSQL;
			cmd.CommandTimeout = 20;
	
			//open a new connection	
			con.Open();
			strMsg = "  Successful connection to '" + dbname
				+ "' db using IBM DB2 .NET Data Provider";
			Console.WriteLine(strMsg);
				
			//get info about the connection
			strMsg = "\t Database: " + con.Database.ToString()
				+ "\n\t ServerType: " + con.ServerType
				+ "\n\t ServerVersion: " 
				+ con.ServerVersion.ToString();
			Console.WriteLine(strMsg);

	
			//execute the SQL statement	
			rdr = cmd.ExecuteReader(CommandBehavior.SingleResult);

	
			//get value from retrieved records
			v_IBMREQD = "";
			while (rdr.Read() == true)
			{
				v_IBMREQD = rdr.GetString(0);
			}
			strMsg = "  Successful retrieval of record. Column" +
				" 'IBMREQD' has a value of '" + v_IBMREQD + "'";
			Console.WriteLine(strMsg);

			//close the reader
			rdr.Close();
			
			//close the connection object
			con.Close();
			strMsg = "  Successful Disconnection from" +
				" database '" + dbname + "'";
			Console.WriteLine(strMsg);
		}
		catch (DB2Exception myException)
		{
			for(i = 0; i < myException.Errors.Count;i++)
			{
				strMsg = "Index #" + i.ToString()
					+ "\n Message: " + myException.Errors[i].Message 
					+ "\n Native: " + myException.Errors[i].NativeError.ToString()
					+ "\n Source: " + myException.Errors[i].Source
					+ "\n SQL: " + myException.Errors[i].SQLState;
				Console.WriteLine(strMsg);
			}
		}																																																																																	 
		catch (Exception e)
		{
			Console.WriteLine("\n Source: " + e.Source + "\n Message: " + e.Message );
		}
		finally
		{
			//Clean-up

			//close the reader
			if (rdr != null)
			{
				if (rdr.IsClosed == false) rdr.Close();
			}

			//close the connection
			if (con != null)
			{
				if (con.State != ConnectionState.Closed) con.Close();
			}
		}

		//to stop the console window from closing too quickly
		Console.WriteLine("Press 'Enter' key to exit...");
		i = Console.Read();
	} // Main
} // ConnectDb