'----------------------------------------------------------------------------
'
'************************************************************************
' * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
' *                                                                     *
' * This sample program is owned by International Business Machines     *
' * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
' * and licensed, not sold.                                             *
' *                                                                     *
' * You may copy, modify, and distribute this sample program in any     *
' * form without payment to IBM,  for any purpose including developing, *
' * using, marketing or distributing programs that include or are       *
' * derivative works of the sample program.                             *
' *                                                                     *
' * The sample program is provided to you on an "AS IS" basis, without  *
' * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
' * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
' * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
' * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
' * limitation of implied warranties, so the above limitations or       *
' * exclusions may not apply to you.  IBM shall not be liable for any   *
' * damages you suffer as a result of using, modifying or distributing  *
' * the sample program or its derivatives.                              *
' *                                                                     *
' * Each copy of any portion of this sample program or any derivative   *
' * work,  must include the above copyright notice and disclaimer of    *
' * warranty.                                                           *
' *                                                                     *
'************************************************************************
'
'//***************************************************************************
'//
'// SOURCE FILE NAME: dbConn_vb_adoNET_msoledbnet.vb
'//
'// DESCRIPTION:      How to connect to a database using
'//                    Microsoft OLE DB .NET Data Provider
'//
'//***************************************************************************
'
''----------------------------------------------------------------------------
Option Explicit On 

Imports Microsoft.VisualBasic
Imports System
Imports System.Data
Imports System.Data.OleDb

Public Class ConnectDb
    Public Shared Sub Main(ByVal args() As String)

        Dim err As OleDbError
        Dim cmd As OleDbCommand
        Dim con As OleDbConnection
        Dim connectString As String
        Dim i As Integer
        Dim rdr As OleDbDataReader
        Dim strMsg As String
        Dim strSQL As String
        Dim dbname As String
        Dim pwd As String
        Dim uid As String
        Dim v_IBMREQD As String

        'retrieve command-line parameters
        If args.Length = 3 Then
            dbname = args(0)
            uid = args(1)
            pwd = args(2)
        Else
            'no command-line parameters specified, use default
            dbname = "SAMPLE"
            uid = ""
            pwd = ""
        End If

        connectString = "DSN=" + dbname + ";UID=" + uid + ";PWD=" + pwd + ";"
        'if needed, uncomment & specify rest of connection string's
        '      keyword/value pairs
        connectString += "Provider='IBMDADB2';"
        'connectString += "Driver={IBM DB2 ODBC DRIVER};"
        'connectString += "Server=aries.xyz.com:50000;"
        'connectString += "Connect Timeout=60;"
        'connectString += "Pooling=true;"
        'connectString += "Min Pool Size=0;"
        'connectString += "Max Pool Size=12;"
        'connectString += "Connection Reset=true;"
        'connectString += "Connection Lifetime=15;"

        Try
            'initialize connection object
            con = New OleDbConnection(connectString)

            'define SQL query
            strSQL = "SELECT * FROM SYSIBM.SYSDUMMY1"

            'initialize command object
            cmd = New OleDbCommand()

            'set up command object properties
            cmd.Connection = con
            cmd.CommandText = strSQL
            cmd.CommandTimeout = 20

            'open a new connection
            con.Open()
            strMsg = "  Successful connection to '" + dbname + _
                              "' db using Microsoft OLE DB .NET Data Provider"
            Console.WriteLine(strMsg)

            'get info about the connection
            strMsg = vbTab + "ServerVersion: " + con.ServerVersion.ToString()
            Console.WriteLine(strMsg)

            'execute the SQL statement
            rdr = cmd.ExecuteReader(CommandBehavior.SingleResult)

            'get value from retrieved records
            While rdr.Read()
                v_IBMREQD = rdr.GetString(0)
            End While
            strMsg = "  Successful retrieval of record.  Column 'IBMREQD'" + _
                               " has a value of '" + v_IBMREQD + "'"
            Console.WriteLine(strMsg)

            'close the reader
            rdr.Close()

            'close the connection object
            con.Close()
            strMsg = "  Successful Disconnection from database '" + _
                               dbname + "'"
            Console.WriteLine(strMsg)

        Catch myException As OleDbException
            For i = 0 To myException.Errors.Count - 1
                strMsg = "Index #" + i.ToString() + ControlChars.Cr _
                   + "Message: " + myException.Errors(i).Message + ControlChars.Cr _
                   + "Native: " + myException.Errors(i).NativeError.ToString() + ControlChars.Cr _
                   + "Source: " + myException.Errors(i).Source + ControlChars.Cr _
                   + "SQL: " + myException.Errors(i).SQLState + ControlChars.Cr
                Console.WriteLine(strMsg)
            Next i
        Catch e As Exception
            Console.WriteLine(e.Message)
        Finally
            'Clean-up

            'close the reader
            If Not (rdr Is Nothing) Then
                If rdr.IsClosed() = False Then rdr.Close()
            End If

            'close the connection
            If Not (con Is Nothing) Then
                If con.State <> ConnectionState.Closed Then con.Close()
            End If
        End Try

        'to stop the console window from closing too quickly
        Console.WriteLine("Press 'Enter' key to exit...")
        i = Console.Read()
    End Sub ' Main
End Class ' ConnectDb
