'----------------------------------------------------------------------------
'
'************************************************************************
' * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
' *                                                                     *
' * This sample program is owned by International Business Machines     *
' * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
' * and licensed, not sold.                                             *
' *                                                                     *
' * You may copy, modify, and distribute this sample program in any     *
' * form without payment to IBM,  for any purpose including developing, *
' * using, marketing or distributing programs that include or are       *
' * derivative works of the sample program.                             *
' *                                                                     *
' * The sample program is provided to you on an "AS IS" basis, without  *
' * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
' * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
' * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
' * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
' * limitation of implied warranties, so the above limitations or       *
' * exclusions may not apply to you.  IBM shall not be liable for any   *
' * damages you suffer as a result of using, modifying or distributing  *
' * the sample program or its derivatives.                              *
' *                                                                     *
' * Each copy of any portion of this sample program or any derivative   *
' * work,  must include the above copyright notice and disclaimer of    *
' * warranty.                                                           *
' *                                                                     *
'************************************************************************
'
'//***************************************************************************
'//
'// SOURCE FILE NAME: dbConn_vb_ado_ibmdadb2.bas
'//
'// DESCRIPTION:      How to connect to a database using
'//                    IBM OLE DB Provider for DB2
'//
'//***************************************************************************
'
''----------------------------------------------------------------------------
Option Explicit

Public Sub Main()
  'define the error handler
  On Error GoTo Main_Error

  Dim args() As String
  Dim error As ADODB.error
  Dim cmd As ADODB.Command
  Dim cmdline As String
  Dim con As ADODB.Connection
  Dim connectString As String
  Dim prp As ADODB.Property
  Dim rst As ADODB.Recordset
  Dim strMsg As String
  Dim strSQL As String
  Dim dbname As String
  Dim uid As String
  Dim pwd As String

  'retrieve command-line parameters & set up connection string
  ' basic handling of command-line parameters
  cmdline = Command()
  If Len(cmdline) > 0 Then
    args = Split(Trim$(cmdline), " ", 3, vbBinaryCompare)
    If UBound(args) = 2 Then
      dbname = args(0)
      uid = args(1)
      pwd = args(2)
    Else
      'impartial command-line parameters specified, use default
      dbname = "SAMPLE"
      uid = ""
      pwd = ""
    End If
  Else
    'no command-line parameters specified, use default
      dbname = "SAMPLE"
      uid = ""
      pwd = ""
  End If
  
  connectString = "DSN=" + dbname + ";UID=" + uid + ";PWD=" + pwd + ";"
  'if ODBC data provider, uncomment & specify driver
  'connectString = connectString + "Driver={IBM DB2 ODBC DRIVER};"

  'initialize connection object
  Set con = New ADODB.Connection

  'set up connection object properties
  con.ConnectionString = connectString
  con.Provider = "IBMDADB2"
  con.CursorLocation = adUseClient
       'if needed uncomment & specify rest of the properties
  'con.Mode = adModeReadWrite
  'con.CommandTimeOut = 30
  'con.Attributes = 0
  'con.IsolationLevel = adXactReadCommited

  'open a new connection
  con.Open
  strMsg = "  Successful connection to '" + dbname + _
           "' db using IBM OLE DB Provider for DB2" + vbCrLf

  'get info about the connection
  strMsg = strMsg & vbTab & "Data Source Name" & vbTab & _
            ":>" & con.Properties("Data Source Name") & vbCr
  strMsg = strMsg & vbTab & "DBMS Name" & vbTab & ":>" & _
            con.Properties("DBMS Name") & vbCr
  strMsg = strMsg & vbTab & "DBMS Version" & vbTab & ":>" & _
             con.Properties("DBMS Version") & vbCr

  'define SQL query
  strSQL = "SELECT * FROM SYSIBM.SYSDUMMY1"

  'initialize command object
  Set cmd = New ADODB.Command

  'set up command object properties
  Set cmd.ActiveConnection = con
  cmd.CommandText = strSQL

  'execute the SQL statement
  Set rst = cmd.Execute()

  'get value from retrieved records
  strMsg = strMsg + "  Successful retrieval of record. Column" + _
                    " 'IBMREQD' has a value of '" + _
                    rst.Fields.Item("IBMREQD").Value + "'" + vbCrLf

  'close the recorset
  rst.Close

  'close the connection object
  con.Close
  strMsg = strMsg + "  Successful Disconnection from database '" + dbname + "'"

Main_Exit:
  'Display Message
  MsgBox strMsg

  'Clean up
  'close the recorset
    If Not rst Is Nothing Then
        If rst.State <> adStateClosed Then rst.Close
    End If

  'release the recordset handler
  Set rst = Nothing

  'release the command handler
  Set cmd = Nothing

  'close the connection
    If Not con Is Nothing Then
        If con.State <> adStateClosed Then con.Close
    End If

  'release the handler
  Set con = Nothing

  Exit Sub

Main_Error:
  'display provider errors from connection object
  If con.Errors.Count > 0 Then
    For Each error In con.Errors
        strMsg = " Error number:" & error.Number & _
        " """ & error.Description & """ (" & error.Source & _
        ") (Native error: " & error.NativeError & ")" & vbCrLf
        MsgBox strMsg, , "Connection Error"
    Next
  End If

  'display runtime errors
  If Err <> 0 Then
        MsgBox Err.Source & "-->" & Err.Description, , "Runtime Error"
  End If

  'go to Main_Exit to clean-up before exiting
  Resume Main_Exit

End Sub