//----------------------------------------------------------------------------
//
//************************************************************************
// * (c) Copyright IBM Corp. 2003  All rights reserved.                  *
// *                                                                     *
// * This sample program is owned by International Business Machines     *
// * Corporation or one of its subsidiaries ("IBM") and is copyrighted   *
// * and licensed, not sold.                                             *
// *                                                                     *
// * You may copy, modify, and distribute this sample program in any     *
// * form without payment to IBM,  for any purpose including developing, *
// * using, marketing or distributing programs that include or are       *
// * derivative works of the sample program.                             *
// *                                                                     *
// * The sample program is provided to you on an "AS IS" basis, without  *
// * warranty of any kind.  IBM HEREBY  EXPRESSLY DISCLAIMS ALL          *
// * WARRANTIES EITHER EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO *
// * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTIC- *
// * ULAR PURPOSE. Some jurisdictions do not allow for the exclusion or  *
// * limitation of implied warranties, so the above limitations or       *
// * exclusions may not apply to you.  IBM shall not be liable for any   *
// * damages you suffer as a result of using, modifying or distributing  *
// * the sample program or its derivatives.                              *
// *                                                                     *
// * Each copy of any portion of this sample program or any derivative   *
// * work,  must include the above copyright notice and disclaimer of    *
// * warranty.                                                           *
// *                                                                     *
//************************************************************************
//
//***************************************************************************
//
// SOURCE FILE NAME: dbConn_vc_ado_ibmdadb2.cpp
//
// DESCRIPTION:      How to connect to a database using
//                    IBM OLE DB Provider for DB2
//
//***************************************************************************
//
//----------------------------------------------------------------------------
#include "stdafx.h"

// Make sure that following ADO library headers declarations are copied
//    into "StdAfx.h".
// Start copying
// Import ADO Library headers.
//#import "C:\program files\common files\system\ado\msado15.dll" \
//	no_namespace \
//	rename( "EOF", "adoEOF")
//
//#include <oledb.h>
//#include <stdio.h>
//#include <conio.h>
// Stop copying

int main(int argc, char* argv[])
{
    // initialize OLE
    if(FAILED(::CoInitialize(NULL)))
        return -1;

    _bstr_t dbname;
    _bstr_t pwd;
    _bstr_t strCon;
    _bstr_t strMsg;
    _bstr_t strSQL;
    _bstr_t uid;
    _CommandPtr pCmd  = NULL;			// ADO command object
    _ConnectionPtr pConnection = NULL;	// ADO connection object
    _RecordsetPtr  pRst = NULL;			// ADO recordset object
    ErrorPtr pErr = NULL;				// ADO error object
    HRESULT  hr;
    long nCount, i;
    PropertyPtr pPrp = NULL;			// ADO property object

    // retrieve command-line parameters & set up connection string
    if (argc != 4)
    {
    	dbname = _bstr_t("sample");
    	uid = _bstr_t("");
    	pwd = _bstr_t("");
    }
    else
    {
    	dbname = _bstr_t(argv[1]);
    	uid = _bstr_t(argv[2]);
    	pwd = _bstr_t(argv[3]);
    }
    strCon = _bstr_t("DSN=") + dbname
       	     + _bstr_t(";UID=") + uid
       	     + _bstr_t(";PWD=") + pwd + _bstr_t(";");   
    //if ODBC data provider, uncomment & specify driver
    //strCon += _bstr_t("Driver={IBM DB2 ODBC DRIVER};");

    try
    {
        // initialize connection object
        hr = pConnection.CreateInstance(__uuidof(Connection));
        if FAILED(hr)
        {
         _com_issue_error(hr);
        }
        
        //set up connection object properties
        pConnection->ConnectionString = strCon;
        pConnection->CursorLocation = adUseClient;
        pConnection->Provider = "IBMDADB2";
        	//if needed uncomment & specify rest of the properties
        //pConnection->Attributes = 0;
        //pConnection->CommandTimeOut = 30;
        //pConnection->IsolationLevel = adXactReadCommited;
        //pConnection->Mode = adModeReadWrite;

        // Open connection
        pConnection->Open("","","",adConnectUnspecified);
        strMsg = _bstr_t("  Successful connection to '");
        strMsg += dbname ;
        strMsg += _bstr_t("' db using IBM OLE DB Provider for DB2");
        printf("%s\n",(LPCSTR)strMsg);
        
        //get info about the connection
        printf("\tData Source Name :> %s \n",(LPCSTR) (_bstr_t) 
            pConnection->Properties->GetItem("Data Source Name")->Value);
        printf("\tDBMS Name :> %s \n",(LPCSTR) (_bstr_t) 
            pConnection->Properties->GetItem("DBMS Name")->Value);
        printf("\tDBMS Version :> %s \n",(LPCSTR) (_bstr_t)
            pConnection->Properties->GetItem("DBMS Version")->Value);

	
        //define SQL query
        strSQL = _bstr_t("SELECT * FROM SYSIBM.SYSDUMMY1");
        
        // initialize command object
        hr = pCmd.CreateInstance(__uuidof(Command));
        if FAILED(hr)
        {
         _com_issue_error(hr);
        }
        
        //set up connection object properties        
        pCmd->ActiveConnection = pConnection;
        pCmd->CommandText = strSQL;
        

        //execute the SQL statement
        pRst = pCmd->Execute(NULL,NULL,adOptionUnspecified); 

        //get value from retrieved records
        strMsg  = _bstr_t("  Successful retrieval of record.");
        strMsg += _bstr_t(" Column 'IBMREQD' has a value of '");
        strMsg += _bstr_t(pRst->Fields->Item["IBMREQD"]->Value) ;
        strMsg += _bstr_t("'");
        printf("%s\n",(LPCSTR)strMsg);
  
        //close the recorset
        pRst->Close();

        //close the connection
        pConnection->Close();
        strMsg = _bstr_t("  Successful Disconnection from database '");
        strMsg += dbname ;
        strMsg += _bstr_t("'");
        printf("%s\n",(LPCSTR)strMsg);
    }
    catch(_com_error &e)
    {
	// display provider errors from connection object
	if( (pConnection->Errors->Count) > 0)
	{
	    nCount = pConnection->Errors->Count;
	    for(i = 0;i < nCount;i++)
	    {
	        pErr = pConnection->Errors->GetItem(i);
	        printf("\n\tError number: %x\n\t%s\n\t(%s)\n\t(Native error: %d)",
	            pErr->Number, pErr->Description, (LPCSTR)pErr->Source,
	            (LPCSTR)pErr->NativeError);
	    }
	}

	// display runtime errors
        _bstr_t bstrSource(e.Source());
        _bstr_t bs =  _bstr_t("\tCode: ")
			+ _bstr_t(e.Error())
			+ _bstr_t("\n\tMessage: ") 
			+ _bstr_t(e.ErrorMessage())
			+ _bstr_t("\n\tDescription: ") 
			+ _bstr_t(e.Description());        
        printf("\n\tError reported by: %s\n", (LPCSTR) bstrSource);
        printf("%s\n", (LPCSTR) bs);        
    }

    // Clean up
    
    // close the recordset & release the handler
    if (pRst != NULL)
    {
        if (pRst->State != adStateClosed)
        {
            pRst->Close();
        }
		pRst = NULL;
    }
    
    // close the connection & release the handler
    if (pConnection != NULL)
    {
        if (pConnection->State != adStateClosed)
        {
            pConnection->Close();
        }
		pConnection = NULL;
    }
    
    //to stop the console window from closing too quickly
    printf("\nPress any key to exit...");    
    getch();

    // Terminate OLE
    ::CoUninitialize();
    return 0;
}